/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.jcg;

import com.ibm.mq.jms.MQConnectionFactory;
import com.ibm.msg.client.wmq.WMQConstants;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.Session;

/**
 *
 * @author omozegieaziegbe
 */
public class IbmJmsExample {

    private static final String HOSTNAME = "localhost";
    private static final int PORT = 1414; // Default MQ port
    private static final String CHANNEL = "DEV.APP.SVRCONN";
    private static final String QUEUE_MANAGER = "QM1";
    private static final String QUEUE_NAME = "DEV.QUEUE.1";

    public static ConnectionFactory createConnectionFactory() throws JMSException {
        MQConnectionFactory connectionFactory = new MQConnectionFactory();
        connectionFactory.setHostName(HOSTNAME);
        connectionFactory.setPort(PORT);
        connectionFactory.setChannel(CHANNEL);
        connectionFactory.setQueueManager(QUEUE_MANAGER);
        connectionFactory.setTransportType(WMQConstants.WMQ_CM_CLIENT); // Client mode

        return connectionFactory;
    }

    public static void sendObjectMessage(ConnectionFactory connectionFactory) throws JMSException {
        try (Connection connection = connectionFactory.createConnection(); Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE)) {

            Queue queue = session.createQueue(QUEUE_NAME);
            MessageProducer producer = session.createProducer(queue);

            // Create and send an ObjectMessage
            Employee employee = new Employee("Mr Fish", 1983);
            ObjectMessage objectMessage = session.createObjectMessage(employee);
            producer.send(objectMessage);

            System.out.println("ObjectMessage sent to queue." + employee.getName() + " " + employee.getId());
        }
    }

    public static void receiveObjectMessage(ConnectionFactory connectionFactory) throws JMSException {
        try (Connection connection = connectionFactory.createConnection(); Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE)) {

            Queue queue = session.createQueue(QUEUE_NAME);
            MessageConsumer consumer = session.createConsumer(queue);

            connection.start();

            // Receive the ObjectMessage
            ObjectMessage receivedMessage = (ObjectMessage) consumer.receive(5000); // Wait for up to 5 seconds
            if (receivedMessage != null) {
                Employee receivedObject = (Employee) receivedMessage.getObject();
                System.out.println("Received Object: " + receivedObject.toString() + ", ID: " + receivedObject.getId());
            } else {
                System.out.println("No message received.");
            }
        }
    }

    public static void main(String[] args) throws JMSException {
        ConnectionFactory connectionFactory = createConnectionFactory();

        sendObjectMessage(connectionFactory);
        receiveObjectMessage(connectionFactory);
    }
}
