/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.jcg;

import com.ibm.mq.jms.MQConnectionFactory;
import com.ibm.msg.client.wmq.WMQConstants;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.Session;

/**
 *
 * @author omozegieaziegbe
 */
public class MessageReceiver {

    private static final String HOSTNAME = "localhost";
    private static final int PORT = 1414; // Default MQ port
    private static final String CHANNEL = "DEV.APP.SVRCONN";
    private static final String QUEUE_MANAGER = "QM1";
    private static final String QUEUE_NAME = "DEV.QUEUE.1";

    public static ConnectionFactory createConnectionFactory() throws JMSException {
        MQConnectionFactory connectionFactory = new MQConnectionFactory();
        connectionFactory.setHostName(HOSTNAME);
        connectionFactory.setPort(PORT);
        connectionFactory.setChannel(CHANNEL);
        connectionFactory.setQueueManager(QUEUE_MANAGER);
        connectionFactory.setTransportType(WMQConstants.WMQ_CM_CLIENT); // Client mode

        return connectionFactory;
    }

    public static void receiveObjectMessage(ConnectionFactory connectionFactory) throws JMSException {

        Connection connection = null;
        Session session = null;
        try {
            connection = connectionFactory.createConnection();
            session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

            Queue queue = session.createQueue(QUEUE_NAME);
            MessageConsumer consumer = session.createConsumer(queue);

            connection.start();

            // Continuously receive messages from the queue
            Message message;
            while ((message = consumer.receive(1000)) != null) {
                if (message instanceof ObjectMessage) {
                    ObjectMessage objectMessage = (ObjectMessage) message;
                    Employee employee = (Employee) objectMessage.getObject();

                    // Retrieve custom properties
                    String senderName = objectMessage.getStringProperty("SenderName");
                    int messagePriority = objectMessage.getIntProperty("MessagePriority");
                    long timestamp = objectMessage.getLongProperty("Timestamp");
                    String messageId = message.getJMSMessageID();

                    System.out.println("Received ObjectMessage: " + employee);
                    System.out.println("Sender Name: " + senderName);
                    System.out.println("Message Priority: " + messagePriority);
                    System.out.println("Timestamp: " + timestamp);
                    System.out.println("Message ID: " + messageId);
                } else {
                    System.out.println("Received non-ObjectMessage: " + message);
                }
            }

            System.out.println("No more messages in the queue.");

        } catch (JMSException e) {
        } finally {
            // Ensure session and connection are closed to prevent lingering threads
            if (session != null) {
                session.close();
            }
            if (connection != null) {
                connection.close();
            }
        }
    }

    public static void main(String[] args) throws JMSException {
        ConnectionFactory connectionFactory = createConnectionFactory();

        //sendObjectMessage(connectionFactory);
        receiveObjectMessage(connectionFactory);
    }
}
