/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.jcg;

import com.ibm.mq.jms.MQConnectionFactory;
import com.ibm.msg.client.wmq.WMQConstants;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.Session;

/**
 *
 * @author omozegieaziegbe
 */
public class MessageSender {

    private static final String HOSTNAME = "localhost";
    private static final int PORT = 1414; // Default MQ port
    private static final String CHANNEL = "DEV.APP.SVRCONN";
    private static final String QUEUE_MANAGER = "QM1";
    private static final String QUEUE_NAME = "DEV.QUEUE.1";

    public static ConnectionFactory createConnectionFactory() throws JMSException {
        MQConnectionFactory connectionFactory = new MQConnectionFactory();
        connectionFactory.setHostName(HOSTNAME);
        connectionFactory.setPort(PORT);
        connectionFactory.setChannel(CHANNEL);
        connectionFactory.setQueueManager(QUEUE_MANAGER);
        connectionFactory.setTransportType(WMQConstants.WMQ_CM_CLIENT); // Client mode

        return connectionFactory;
    }

    public static void sendObjectMessage(ConnectionFactory connectionFactory) throws JMSException {

        Connection connection = null;
        Session session = null;
        try {
            connection = connectionFactory.createConnection();
            session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

            // Create a queue
            Queue queue = session.createQueue(QUEUE_NAME);

            // Create a producer
            MessageProducer producer = session.createProducer(queue);

            // Create and send an ObjectMessage
            Employee employee = new Employee("Mr Rice", 1984);
            ObjectMessage objectMessage = session.createObjectMessage(employee);
            
            // Set custom properties
            objectMessage.setStringProperty("SenderName", "Speed Racer");
            objectMessage.setIntProperty("MessagePriority", 3);
            objectMessage.setLongProperty("Timestamp", System.currentTimeMillis());
            producer.send(objectMessage);

            System.out.println("ObjectMessage sent to queue " +  "Name: " + employee.getName() + " ID: " + employee.getId());

        } catch (JMSException e) {
        } finally {
            if (session != null) {
                session.close();
            }
            if (connection != null) {
                connection.close();
            }
        }
    }

    public static void main(String[] args) throws JMSException {
        ConnectionFactory connectionFactory = createConnectionFactory();
        sendObjectMessage(connectionFactory);
    }
}
